/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global define*/

/**
 * Keyboard helper module.
 * @namespace ArchiveManager/helpers/keyboard
 * @memberof ArchiveManager/helpers
 * @requires {@link core/event}
 * @requires {@link core/window}
 */
define({
    name: 'helpers/keyboard',
    requires: [
        'core/event',
        'core/window'
    ],
    def: function helpersKeyboard(e, window) {
        'use strict';

        /**
         * Handles softkeyboardchange event on window object.
         * @param {event} ev
         * @fires "opened"
         * @fires "closed"
         */
        function onKeyboardChange(ev) {
            if (ev.state === 'on') {
                e.fire('opened');
            } else {
                e.fire('closed');
            }
        }

        /**
         * Initializes the module.
         * @memberof ArchiveManager/helpers/keyboard
         */
        function init() {
            window.addEventListener('softkeyboardchange', onKeyboardChange);
        }

        return {
            init: init
        };
    }
});
